; *********************************************************************************** */
;   Filename:   msp430x12x2.inc                                                       */
;   Author:     Thomas Dorn, DT-Systems, www.dt-systems.de                            */
;   Date:       20.05.2006                                                            */
;                                                                                     */
;   Brief: Hardware specific header                                                   */
;                                                                                     */
;************************************************************************************ */
;
; ---------- timer definitions ----------------------------------------------
;
TAIV        EQU     0x012E          ; timer A interrupt vector word
TACTL       EQU     0x0160          ; Timer A Control
TACCTL0     EQU     0x0162          ; Timer A Capture/Compare Control 0
TACCTL1     EQU     0x0164          ; Timer A Capture/Compare Control 1
TACCTL2     EQU     0x0166          ; Timer A Capture/Compare Control 2
TAR         EQU     0x0170          ; Timer A
TACCR0      EQU     0x0172          ; Timer A Capture/Compare 0
TACCR1      EQU     0x0174          ; Timer A Capture/Compare 1
TACCR2      EQU     0x0176          ; Timer A Capture/Compare 2


CCIFG       EQU     0x0001          ; Capture/compare interrupt flag */    
COV         EQU     0x0002          ; Capture/compare overflow flag */     
OUT         EQU     0x0004          ; PWM Output signal if output mode 0 */
CCI         EQU     0x0008          ; Capture input signal (read) */       
CCIE        EQU     0x0010          ; Capture/compare interrupt enable */  
OUTMOD      EQU     0x0080          ; Output mode */                       
CAP         EQU     0x0100          ; Capture mode: 1 /Compare mode : 0 */ 
SCCI        EQU     0x0400          ; Latched capture signal (read) */    
SCS         EQU     0x0800          ; Capture sychronize */               
CCIS        EQU     0x2000          ; Capture input select */             
CM          EQU     0x8000          ; Capture mode */   

; ---------- special function definitions -----------------------------------
;
IE1         EQU     0x0000          ; Interrupt Enable 1
bWDTIE      EQU     0x01            ;
bOFIE       EQU     0x02            ;
bNMIIE      EQU     0x10            ;
bACCVIE     EQU     0x20            ;

IFG1        EQU     0x0002          ; Interrupt Flag 1
bWDTIFG     EQU     0x01
bOFIFG      EQU     0x02
bNMIIFG     EQU     0x10

IE2         EQU     0x0001          ; Interrupt Enable 2
U0IE        EQU     IE2             ; UART0 Interrupt Enable Register 
bURXIE0     EQU     0x01
bUTXIE0     EQU     0x02

IFG2        EQU     0x0003          ; Interrupt Flag 2
U0IFG       EQU     IFG2            ; UART0 Interrupt Flag Register
bURXIFG0    EQU     0x01
bUTXIFG0    EQU     0x02

ME2         EQU     0x0005          ; Module Enable 2
U0ME        EQU     ME2             ; UART0 Module Enable Register
bURXE0      EQU     0x01
bUTXE0      EQU     0x02
bUSPIE0     EQU     0x01

; ---------- watchdog definitions --------------------------------------------
;
WDTCTL      EQU     0x0120           ; Watchdog Timer Control

bWDTIS0     EQU     0x01
bWDTIS1     EQU     0x02
bWDTSSEL    EQU     0x04
bWDTCNTCL   EQU     0x08
bWDTTMSEL   EQU     0x10
bWDTNMI     EQU     0x20
bWDTNMIES   EQU     0x40
bWDTHOLD    EQU     0x80

WDTPW_W     EQU     0x5A00
WDTPW_R     EQU     0x6900


